package
Version:
v1.1.1
Opens a new window with list of versions in this module.
Published: Nov 24, 2021
License: GPL-3.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Exception struct {
C int `json:"code"`
M string `json:"message"`
D interface{} `json:"data"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.